@@ -1,6 +1,6 @@
 # SPDX-License-Identifier: Apache-2.0
 
-import numpy as np  # type: ignore
+import numpy as np
 
 
 def abs(input: np.ndarray) -> np.ndarray:
