@@ -1,20 +1,20 @@
 # SPDX-License-Identifier: Apache-2.0
 
-from collections import defaultdict
 import inspect
+from collections import defaultdict
 from textwrap import dedent
-from typing import Dict, List, Tuple, Type, Sequence, Any
+from typing import Any, Dict, List, Tuple, Type
 
-import numpy as np  # type: ignore
+import numpy as np
 
 
 def process_snippet(op_name: str, name: str, export: Any) -> Tuple[str, str]:
-    snippet_name = name[len('export_'):] or op_name.lower()
+    snippet_name = name[len("export_") :] or op_name.lower()
     source_code = dedent(inspect.getsource(export))
     # remove the function signature line
     lines = source_code.splitlines()
-    assert lines[0] == '@staticmethod'
-    assert lines[1].startswith('def export')
+    assert lines[0] == "@staticmethod"
+    assert lines[1].startswith("def export")
     return snippet_name, dedent("\n".join(lines[2:]))
 
 
@@ -24,12 +24,13 @@ Snippets: Dict[str, List[Tuple[str, str]]] = defaultdict(list)
 class _Exporter(type):
     exports: Dict[str, List[Tuple[str, str]]] = defaultdict(list)
 
-    def __init__(cls, name: str, bases: Tuple[Type[Any], ...], dct: Dict[str, Any]) -> None:
+    def __init__(
+        cls, name: str, bases: Tuple[Type[Any], ...], dct: Dict[str, Any]
+    ) -> None:
         for k, v in dct.items():
-            if k.startswith('export'):
+            if k.startswith("export"):
                 if not isinstance(v, staticmethod):
-                    raise ValueError(
-                        'Only staticmethods could be named as export.*')
+                    raise ValueError("Only staticmethods could be named as export.*")
                 export = getattr(cls, k)
                 Snippets[name].append(process_snippet(name, k, export))
                 # export functions should call expect and so populate
