@@ -1,20 +1,23 @@
 # SPDX-License-Identifier: Apache-2.0
 
-import numpy as np  # type: ignore
+import numpy as np
 
 import onnx
+
 from ..base import Base
 from . import expect
 
 
-def argmin_use_numpy(data: np.ndarray, axis: int = 0, keepdims: int = 1) -> (np.ndarray):
+def argmin_use_numpy(data: np.ndarray, axis: int = 0, keepdims: int = 1) -> np.ndarray:
     result = np.argmin(data, axis=axis)
-    if (keepdims == 1):
+    if keepdims == 1:
         result = np.expand_dims(result, axis)
     return result.astype(np.int64)
 
 
-def argmin_use_numpy_select_last_index(data: np.ndarray, axis: int = 0, keepdims: int = True) -> (np.ndarray):
+def argmin_use_numpy_select_last_index(
+    data: np.ndarray, axis: int = 0, keepdims: int = True
+) -> np.ndarray:
     data = np.flip(data, axis)
     result = np.argmin(data, axis=axis)
     result = data.shape[axis] - result - 1
@@ -24,26 +27,29 @@ def argmin_use_numpy_select_last_index(data: np.ndarray, axis: int = 0, keepdims
 
 
 class ArgMin(Base):
-
     @staticmethod
     def export_no_keepdims() -> None:
         data = np.array([[2, 1], [3, 10]], dtype=np.float32)
         axis = 1
         keepdims = 0
         node = onnx.helper.make_node(
-            'ArgMin',
-            inputs=['data'],
-            outputs=['result'],
-            axis=axis,
-            keepdims=keepdims)
+            "ArgMin", inputs=["data"], outputs=["result"], axis=axis, keepdims=keepdims
+        )
         # The content of result is : [[1, 0]]
         result = argmin_use_numpy(data, axis=axis, keepdims=keepdims)
-        expect(node, inputs=[data], outputs=[result], name='test_argmin_no_keepdims_example')
+        expect(
+            node,
+            inputs=[data],
+            outputs=[result],
+            name="test_argmin_no_keepdims_example",
+        )
 
         data = np.random.uniform(-10, 10, [2, 3, 4]).astype(np.float32)
         # result's shape: [2, 4]
         result = argmin_use_numpy(data, axis=axis, keepdims=keepdims)
-        expect(node, inputs=[data], outputs=[result], name='test_argmin_no_keepdims_random')
+        expect(
+            node, inputs=[data], outputs=[result], name="test_argmin_no_keepdims_random"
+        )
 
     @staticmethod
     def export_keepdims() -> None:
@@ -51,38 +57,47 @@ class ArgMin(Base):
         axis = 1
         keepdims = 1
         node = onnx.helper.make_node(
-            'ArgMin',
-            inputs=['data'],
-            outputs=['result'],
-            axis=axis,
-            keepdims=keepdims)
+            "ArgMin", inputs=["data"], outputs=["result"], axis=axis, keepdims=keepdims
+        )
         # The content of result is : [[1], [0]]
         result = argmin_use_numpy(data, axis=axis, keepdims=keepdims)
-        expect(node, inputs=[data], outputs=[result], name='test_argmin_keepdims_example')
+        expect(
+            node, inputs=[data], outputs=[result], name="test_argmin_keepdims_example"
+        )
 
         data = np.random.uniform(-10, 10, [2, 3, 4]).astype(np.float32)
         # result's shape: [2, 1, 4]
         result = argmin_use_numpy(data, axis=axis, keepdims=keepdims)
-        expect(node, inputs=[data], outputs=[result], name='test_argmin_keepdims_random')
+        expect(
+            node, inputs=[data], outputs=[result], name="test_argmin_keepdims_random"
+        )
 
     @staticmethod
     def export_default_axes_keepdims() -> None:
         data = np.array([[2, 1], [3, 10]], dtype=np.float32)
         keepdims = 1
         node = onnx.helper.make_node(
-            'ArgMin',
-            inputs=['data'],
-            outputs=['result'],
-            keepdims=keepdims)
+            "ArgMin", inputs=["data"], outputs=["result"], keepdims=keepdims
+        )
 
         # The content of result is : [[0], [0]]
         result = argmin_use_numpy(data, keepdims=keepdims)
-        expect(node, inputs=[data], outputs=[result], name='test_argmin_default_axis_example')
+        expect(
+            node,
+            inputs=[data],
+            outputs=[result],
+            name="test_argmin_default_axis_example",
+        )
 
         data = np.random.uniform(-10, 10, [2, 3, 4]).astype(np.float32)
         # result's shape: [1, 3, 4]
         result = argmin_use_numpy(data, keepdims=keepdims)
-        expect(node, inputs=[data], outputs=[result], name='test_argmin_default_axis_random')
+        expect(
+            node,
+            inputs=[data],
+            outputs=[result],
+            name="test_argmin_default_axis_random",
+        )
 
     @staticmethod
     def export_negative_axis_keepdims() -> None:
@@ -90,19 +105,26 @@ class ArgMin(Base):
         axis = -1
         keepdims = 1
         node = onnx.helper.make_node(
-            'ArgMin',
-            inputs=['data'],
-            outputs=['result'],
-            axis=axis,
-            keepdims=keepdims)
+            "ArgMin", inputs=["data"], outputs=["result"], axis=axis, keepdims=keepdims
+        )
         # The content of result is : [[1], [0]]
         result = argmin_use_numpy(data, axis=axis, keepdims=keepdims)
-        expect(node, inputs=[data], outputs=[result], name='test_argmin_negative_axis_keepdims_example')
+        expect(
+            node,
+            inputs=[data],
+            outputs=[result],
+            name="test_argmin_negative_axis_keepdims_example",
+        )
 
         data = np.random.uniform(-10, 10, [2, 3, 4]).astype(np.float32)
         # result's shape: [2, 3, 1]
         result = argmin_use_numpy(data, axis=axis, keepdims=keepdims)
-        expect(node, inputs=[data], outputs=[result], name='test_argmin_negative_axis_keepdims_random')
+        expect(
+            node,
+            inputs=[data],
+            outputs=[result],
+            name="test_argmin_negative_axis_keepdims_random",
+        )
 
     @staticmethod
     def export_no_keepdims_select_last_index() -> None:
@@ -110,20 +132,31 @@ class ArgMin(Base):
         axis = 1
         keepdims = 0
         node = onnx.helper.make_node(
-            'ArgMin',
-            inputs=['data'],
-            outputs=['result'],
+            "ArgMin",
+            inputs=["data"],
+            outputs=["result"],
             axis=axis,
             keepdims=keepdims,
-            select_last_index=True)
+            select_last_index=True,
+        )
         # result: [[1, 0]]
         result = argmin_use_numpy_select_last_index(data, axis=axis, keepdims=keepdims)
-        expect(node, inputs=[data], outputs=[result], name='test_argmin_no_keepdims_example_select_last_index')
+        expect(
+            node,
+            inputs=[data],
+            outputs=[result],
+            name="test_argmin_no_keepdims_example_select_last_index",
+        )
 
         data = np.random.uniform(-10, 10, [2, 3, 4]).astype(np.float32)
         # result's shape: [2, 4]
         result = argmin_use_numpy_select_last_index(data, axis=axis, keepdims=keepdims)
-        expect(node, inputs=[data], outputs=[result], name='test_argmin_no_keepdims_random_select_last_index')
+        expect(
+            node,
+            inputs=[data],
+            outputs=[result],
+            name="test_argmin_no_keepdims_random_select_last_index",
+        )
 
     @staticmethod
     def export_keepdims_select_last_index() -> None:
@@ -131,40 +164,62 @@ class ArgMin(Base):
         axis = 1
         keepdims = 1
         node = onnx.helper.make_node(
-            'ArgMin',
-            inputs=['data'],
-            outputs=['result'],
+            "ArgMin",
+            inputs=["data"],
+            outputs=["result"],
             axis=axis,
             keepdims=keepdims,
-            select_last_index=True)
+            select_last_index=True,
+        )
         # result: [[1], [0]]
         result = argmin_use_numpy_select_last_index(data, axis=axis, keepdims=keepdims)
-        expect(node, inputs=[data], outputs=[result], name='test_argmin_keepdims_example_select_last_index')
+        expect(
+            node,
+            inputs=[data],
+            outputs=[result],
+            name="test_argmin_keepdims_example_select_last_index",
+        )
 
         data = np.random.uniform(-10, 10, [2, 3, 4]).astype(np.float32)
         # result's shape: [2, 1, 4]
         result = argmin_use_numpy_select_last_index(data, axis=axis, keepdims=keepdims)
-        expect(node, inputs=[data], outputs=[result], name='test_argmin_keepdims_random_select_last_index')
+        expect(
+            node,
+            inputs=[data],
+            outputs=[result],
+            name="test_argmin_keepdims_random_select_last_index",
+        )
 
     @staticmethod
     def export_default_axes_keepdims_select_last_index() -> None:
         data = np.array([[2, 2], [3, 10]], dtype=np.float32)
         keepdims = 1
         node = onnx.helper.make_node(
-            'ArgMin',
-            inputs=['data'],
-            outputs=['result'],
+            "ArgMin",
+            inputs=["data"],
+            outputs=["result"],
             keepdims=keepdims,
-            select_last_index=True)
+            select_last_index=True,
+        )
 
         # result: [[0, 0]]
         result = argmin_use_numpy_select_last_index(data, keepdims=keepdims)
-        expect(node, inputs=[data], outputs=[result], name='test_argmin_default_axis_example_select_last_index')
+        expect(
+            node,
+            inputs=[data],
+            outputs=[result],
+            name="test_argmin_default_axis_example_select_last_index",
+        )
 
         data = np.random.uniform(-10, 10, [2, 3, 4]).astype(np.float32)
         # result's shape: [1, 3, 4]
         result = argmin_use_numpy_select_last_index(data, keepdims=keepdims)
-        expect(node, inputs=[data], outputs=[result], name='test_argmin_default_axis_random_select_last_index')
+        expect(
+            node,
+            inputs=[data],
+            outputs=[result],
+            name="test_argmin_default_axis_random_select_last_index",
+        )
 
     @staticmethod
     def export_negative_axis_keepdims_select_last_index() -> None:
@@ -172,17 +227,28 @@ class ArgMin(Base):
         axis = -1
         keepdims = 1
         node = onnx.helper.make_node(
-            'ArgMin',
-            inputs=['data'],
-            outputs=['result'],
+            "ArgMin",
+            inputs=["data"],
+            outputs=["result"],
             axis=axis,
             keepdims=keepdims,
-            select_last_index=True)
+            select_last_index=True,
+        )
         # result: [[1], [0]]
         result = argmin_use_numpy_select_last_index(data, axis=axis, keepdims=keepdims)
-        expect(node, inputs=[data], outputs=[result], name='test_argmin_negative_axis_keepdims_example_select_last_index')
+        expect(
+            node,
+            inputs=[data],
+            outputs=[result],
+            name="test_argmin_negative_axis_keepdims_example_select_last_index",
+        )
 
         data = np.random.uniform(-10, 10, [2, 3, 4]).astype(np.float32)
         # result's shape: [2, 3, 1]
         result = argmin_use_numpy_select_last_index(data, axis=axis, keepdims=keepdims)
-        expect(node, inputs=[data], outputs=[result], name='test_argmin_negative_axis_keepdims_random_select_last_index')
+        expect(
+            node,
+            inputs=[data],
+            outputs=[result],
+            name="test_argmin_negative_axis_keepdims_random_select_last_index",
+        )
