@@ -1,39 +1,36 @@
 # SPDX-License-Identifier: Apache-2.0
 
-import numpy as np  # type: ignore
+import numpy as np
 
 import onnx
+
 from ..base import Base
 from . import expect
 
 
 class MatMul(Base):
-
     @staticmethod
     def export() -> None:
         node = onnx.helper.make_node(
-            'MatMul',
-            inputs=['a', 'b'],
-            outputs=['c'],
+            "MatMul",
+            inputs=["a", "b"],
+            outputs=["c"],
         )
 
         # 2d
         a = np.random.randn(3, 4).astype(np.float32)
         b = np.random.randn(4, 3).astype(np.float32)
         c = np.matmul(a, b)
-        expect(node, inputs=[a, b], outputs=[c],
-               name='test_matmul_2d')
+        expect(node, inputs=[a, b], outputs=[c], name="test_matmul_2d")
 
         # 3d
         a = np.random.randn(2, 3, 4).astype(np.float32)
         b = np.random.randn(2, 4, 3).astype(np.float32)
         c = np.matmul(a, b)
-        expect(node, inputs=[a, b], outputs=[c],
-               name='test_matmul_3d')
+        expect(node, inputs=[a, b], outputs=[c], name="test_matmul_3d")
 
         # 4d
         a = np.random.randn(1, 2, 3, 4).astype(np.float32)
         b = np.random.randn(1, 2, 4, 3).astype(np.float32)
         c = np.matmul(a, b)
-        expect(node, inputs=[a, b], outputs=[c],
-               name='test_matmul_4d')
+        expect(node, inputs=[a, b], outputs=[c], name="test_matmul_4d")
