@@ -1,11 +1,10 @@
 # SPDX-License-Identifier: Apache-2.0
 import unittest
 
-from onnx import defs, AttributeProto
+from onnx import AttributeProto, defs
 
 
 class TestSchema(unittest.TestCase):
-
     def test_get_schema(self) -> None:
         defs.get_schema("Relu")
 
@@ -13,11 +12,10 @@ class TestSchema(unittest.TestCase):
         defs.get_schema("Conv")
 
     def test_attr_default_value(self) -> None:
-        v = defs.get_schema(
-            "BatchNormalization").attributes['epsilon'].default_value
+        v = defs.get_schema("BatchNormalization").attributes["epsilon"].default_value
         self.assertEqual(type(v), AttributeProto)
         self.assertEqual(v.type, AttributeProto.FLOAT)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
