@@ -6,7 +6,7 @@ default domain ("" or "ai.onnx").
 """
 
 import onnx.onnx_cpp2py_export.version_converter as C
-from onnx import load_from_string, ModelProto
+from onnx import ModelProto, load_from_string
 
 
 def convert_version(model: ModelProto, target_version: int) -> ModelProto:
@@ -159,9 +159,13 @@ def convert_version(model: ModelProto, target_version: int) -> ModelProto:
         - GlobalLpPool from opset 1 to opset 2
     """
     if not isinstance(model, ModelProto):
-        raise ValueError(f'VersionConverter only accepts ModelProto as model, incorrect type: {type(model)}')
+        raise ValueError(
+            f"VersionConverter only accepts ModelProto as model, incorrect type: {type(model)}"
+        )
     if not isinstance(target_version, int):
-        raise ValueError(f'VersionConverter only accepts int as target_version, incorrect type: {type(target_version)}')
+        raise ValueError(
+            f"VersionConverter only accepts int as target_version, incorrect type: {type(target_version)}"
+        )
     model_str = model.SerializeToString()
     converted_model_str = C.convert_version(model_str, target_version)
     return load_from_string(converted_model_str)
